@@ -1,26 +1,27 @@
+from django.contrib.auth.models import User
 from rest_framework import authentication
 from rest_framework import exceptions
-from http_signature import HeaderSigner
+from httpsig import HeaderSigner
 import re
 
 
 class SignatureAuthentication(authentication.BaseAuthentication):
 
-    SIGNATURE_RE = re.compile('signature="(.+?)"')
-    SIGNATURE_HEADERS_RE = re.compile('headers="([\sa-z0-9-]+)"')
+    SIGNATURE_RE = re.compile('.+signature="(.+)",?.*')
+    SIGNATURE_HEADERS_RE = re.compile('.+headers="([\sa-z0-9-\(\)]+)".*')
 
     API_KEY_HEADER = 'X-Api-Key'
 
     def get_signature_from_signature_string(self, signature):
         """Return the signature from the signature header or None."""
-        match = self.SIGNATURE_RE.search(signature)
+        match = self.SIGNATURE_RE.match(signature)
         if not match:
             return None
         return match.group(1)
 
     def get_headers_from_signature(self, signature):
         """Returns a list of headers fields to sign."""
-        match = self.SIGNATURE_HEADERS_RE.search(signature)
+        match = self.SIGNATURE_HEADERS_RE.match(signature)
         if not match:
             raise exceptions.AuthenticationFailed('Bad signature')
         headers_string = match.group(1)
@@ -44,7 +45,7 @@ class SignatureAuthentication(authentication.BaseAuthentication):
         """
         d = {}
         for header in signature_headers:
-            if header == 'request-line':
+            if header == '(request-target)':
                 continue
             d[header] = request.META.get(self.header_canonical(header))
         return d
@@ -65,7 +66,7 @@ class SignatureAuthentication(authentication.BaseAuthentication):
         return signed['authorization']
 
     def fetch_user_data(self, api_key):
-        """Retuns (User instance, API Secret) or None if api_key is bad."""
+        """Retuns a tuple (User instance, API Secret) or None."""
         return None
 
     def authenticate(self, request):
@@ -83,10 +84,7 @@ class SignatureAuthentication(authentication.BaseAuthentication):
         sent_signature = self.get_signature_from_signature_string(sent_string)
 
         # Fetch credentials for API key from the data store.
-        try:
-            user, secret = self.fetch_user_data(api_key)
-        except TypeError:
-            raise exceptions.AuthenticationFailed('Bad API key')
+        user, secret = self.fetch_user_data(api_key)
 
         # Build string to sign from "headers" part of Signature value.
         computed_string = self.build_signature(api_key, secret, request)
@@ -94,6 +92,7 @@ class SignatureAuthentication(authentication.BaseAuthentication):
             computed_string)
 
         if computed_signature != sent_signature:
+            print 'BAD SIGNATURE: expected=%s but got=%s' % (computed_signature, sent_signature)  # DEBUG
             raise exceptions.AuthenticationFailed('Bad signature')
 
-        return (user, api_key)
+        return (user, None)
